fn with_requestor_token_regex<R>(f: impl FnOnce(&Regex) -> R) -> RExpand description
Runs f with as argument a reference to a compiled REQUESTOR_TOKEN_REGEX
that is cached thread locally.
fn with_requestor_token_regex<R>(f: impl FnOnce(&Regex) -> R) -> RRuns f with as argument a reference to a compiled REQUESTOR_TOKEN_REGEX
that is cached thread locally.