pub struct AttributeTypeIdentifier {
inner: String,
}Expand description
Identifier for a yivi attribute type, to us a string with three dots (‘.’).
Identifying credentials
Yivi also permits attribute type identifiers with two dots, which refer to credentials, see for example:
We don’t, but use CredentialTypeIdentifier instead.
Fields
inner: StringImplementations
Sourceimpl AttributeTypeIdentifier
impl AttributeTypeIdentifier
fn deserialize_inner<'de, D>(d: D) -> Result<String, D::Error>where
D: Deserializer<'de>,
Sourcefn validate_inner(inner: &str) -> Result<()>
fn validate_inner(inner: &str) -> Result<()>
Checks that the given string contains three dots (‘.’).