pub struct CredentialTypeIdentifier {
inner: String,
}Expand description
Identifier for a yivi credential type, to us a string with two dots (‘.’).
Fields
inner: StringImplementations
Sourceimpl CredentialTypeIdentifier
impl CredentialTypeIdentifier
fn deserialize_inner<'de, D>(d: D) -> Result<String, D::Error>where
D: Deserializer<'de>,
Sourcefn validate_inner(inner: &str) -> Result<()>
fn validate_inner(inner: &str) -> Result<()>
Checks that the given string contains two dots (‘.’).