ExtendedSessionRequest

Struct ExtendedSessionRequest 

pub struct ExtendedSessionRequest {
    request: SessionRequest,
    pub next_session: Option<NextSessionData>,
}
Fields

request: SessionRequestnext_session: Option<NextSessionData>

Implementations

Source

impl ExtendedSessionRequest

pub fn disclosure(cdc: AttributeConDisCon) -> Self

pub fn issuance(credentials: Vec<CredentialToBeIssued>) -> Self

pub fn next_session(self, url: Url) -> Self

Adds a next_session field

pub fn sign(self, creds: &Credentials<SigningKey>) -> Result<JWT>

Signs this extended session request using the provided requestor credentials.

Documentation: https://docs.yivi.app/session-requests/#jwts-signed-session-requests Reference code for disclosure request: https://github.com/privacybydesign/irmago/blob/d389b4559e007a0fcb4e78d1f6e073c1ad57bc13/requests.go#L957

pub fn open_signed( jwt: &JWT, requestor_credentials: &Credentials<VerifyingKey>, ) -> Result<Self>

Opens the given signed ExtendedSessionRequest.

pub fn mock_disclosure_response( &self, df: impl Fn(&AttributeTypeIdentifier) -> String, ) -> SessionResult

Mocks a valid SessionResult to this ExtendedSessionRequest disclosing the values specified by the df function.

Only simple disclosure requests not involving any ’discon’s are currently supported.

Panics
  • If self is not a disclosure request, or is missing the disclosure field.
  • If one of the ’discon’s is empty, or not a singleton.