SessionResult

Struct SessionResult 

pub struct SessionResult {
    pub token: RequestorToken,
    pub status: Status,
    pub session_type: SessionType,
    pub proof_status: Option<ProofStatus>,
    pub disclosed: Option<Vec<Vec<DisclosedAttribute>>>,
    pub error: Option<RemoteError>,
    pub next_session: Option<RequestorToken>,
}
Fields

token: RequestorTokenstatus: Statussession_type: SessionTypeproof_status: Option<ProofStatus>disclosed: Option<Vec<Vec<DisclosedAttribute>>>error: Option<RemoteError>next_session: Option<RequestorToken>

Implementations

Source

impl SessionResult

fn mock_disclosure(disclosed: Vec<Vec<DisclosedAttribute>>) -> SessionResult

Creates a mock session result containing the specified disclosed attributes

Source

impl SessionResult

pub fn sign( self, creds: &Credentials<SigningKey>, validity: Duration, ) -> Result<JWT>

Signs this session result using the provided yivi server credentials.

https://github.com/privacybydesign/irmago/blob/b1c38f4f2c9da3d3f39b5c21a330bcbd04143f41/server/api.go#L326

pub fn open_signed( jwt: &JWT, server_credentials: &Credentials<VerifyingKey>, ) -> Result<Self>

Opens the given signed SessionResult.

fn validate_except_disclosed(&self) -> Result<()>

Verifies that this SessionResult is valid ignoring the Self::disclosed field.

pub fn validate_and_extract_raw_singles( &self, ) -> Result<impl Iterator<Item = Result<(&AttributeTypeIdentifier, &str)>>>

Verifyies that this SessionResult is valid, and for the first attribute in each inner conjunction returns the AttributeTypeIdentifier and raw value.