pub struct SessionResult {
pub token: RequestorToken,
pub status: Status,
pub session_type: SessionType,
pub proof_status: Option<ProofStatus>,
pub disclosed: Option<Vec<Vec<DisclosedAttribute>>>,
pub error: Option<RemoteError>,
pub next_session: Option<RequestorToken>,
}Expand description
Fields
token: RequestorTokenstatus: Statussession_type: SessionTypeproof_status: Option<ProofStatus>disclosed: Option<Vec<Vec<DisclosedAttribute>>>error: Option<RemoteError>next_session: Option<RequestorToken>Implementations
Sourceimpl SessionResult
impl SessionResult
Sourcefn mock_disclosure(disclosed: Vec<Vec<DisclosedAttribute>>) -> SessionResult
fn mock_disclosure(disclosed: Vec<Vec<DisclosedAttribute>>) -> SessionResult
Creates a mock session result containing the specified disclosed attributes
Sourceimpl SessionResult
impl SessionResult
Sourcepub fn sign(
self,
creds: &Credentials<SigningKey>,
validity: Duration,
) -> Result<JWT>
pub fn sign( self, creds: &Credentials<SigningKey>, validity: Duration, ) -> Result<JWT>
Signs this session result using the provided yivi server credentials.
Sourcepub fn open_signed(
jwt: &JWT,
server_credentials: &Credentials<VerifyingKey>,
) -> Result<Self>
pub fn open_signed( jwt: &JWT, server_credentials: &Credentials<VerifyingKey>, ) -> Result<Self>
Opens the given signed SessionResult.
Sourcefn validate_except_disclosed(&self) -> Result<()>
fn validate_except_disclosed(&self) -> Result<()>
Verifies that this SessionResult is valid ignoring the Self::disclosed field.
Sourcepub fn validate_and_extract_raw_singles(
&self,
) -> Result<impl Iterator<Item = Result<(&AttributeTypeIdentifier, &str)>>>
pub fn validate_and_extract_raw_singles( &self, ) -> Result<impl Iterator<Item = Result<(&AttributeTypeIdentifier, &str)>>>
Verifyies that this SessionResult is valid, and for the first attribute in each inner conjunction
returns the AttributeTypeIdentifier and raw value.